@@ -106,5 +106,9 @@ class TestModelRegionAR(models.Model):
     phone = PhoneNumberField(region="AR", blank=True, null=True)
 
 
-class PhoneNumberWithMaxLength(models.Model):
-    phone = PhoneNumberField(max_length=3)
+class PhoneNumberWithMaxLengthDefault(models.Model):
+    phone = PhoneNumberField(max_length=12, blank=True, default="")
+
+
+class PhoneNumberWithMaxLengthNullable(models.Model):
+    phone = PhoneNumberField(max_length=12, blank=True, null=True)
